.. Skosprovider_rdf documentation master file, created by
   sphinx-quickstart on Thu Oct 24 08:21:49 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Skosprovider_rdf's documentation!
===================================================

This library offers an implementation of the 
:class:`skosprovider.providers.VocabularyProvider`
interface that uses an RDFlib_ graph as input. 

.. toctree::
   :maxdepth: 2
	
   intro
   development
   api
   changes
   glossary

.. _RDFlib: http://rdflib.readthedocs.org/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

